@@ -76,7 +76,7 @@ class Freebox(IPlugin):
 						# 'http://hd2.freebox.fr/pub/remote_control?code=35782633&key=%s' % (rs))
 							for rx in rs['idx_sec']:
 								log.msg(" rx  :  %s" % (rx)
-								log.msg("idx_sec  :  %s" % (int(rs['idx_sec'])))
+								log.msg("idx_sec  :  %s" % rs['idx_sec'])
 								log.msg("idx  :  %s" % (rs['idx']))
 								resp = requests.get ('http://hd2.freebox.fr/pub/remote_control?code=%s&key=%s' % (code_Fb,rs['idx']))
 							log.msg("resp  :  %s" % (resp))
